==> resteasy-microprofile-parent-1.0.0.Final-source-release.zip: resteasy-microprofile-parent-1.0.0.Final/testsuite/integration-tests/src/test/java/org/jboss/resteasy/microprofile/test/client/integration/resource/FollowRedirectsServiceIntf.java <==
/*
 * JBoss, Home of Professional Open Source.
 *
 * Copyright 2021 Red Hat, Inc., and individual contributors
 * as indicated by the @author tags.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jboss.resteasy.microprofile.test.client.integration.resource;

import java.util.List;

import javax.inject.Singleton;
import javax.ws.rs.GET;
import javax.ws.rs.POST;
import javax.ws.rs.Path;
import javax.ws.rs.PathParam;
import javax.ws.rs.core.Response;

import org.eclipse.microprofile.rest.client.inject.RegisterRestClient;

@RegisterRestClient(configKey = "ckName")
@Path("/theService")
@Singleton
public interface FollowRedirectsServiceIntf {
    @GET
    @Path("get")
    List<String> getList();

    @GET
    @Path("tmpRedirect/{p}/{testname}")
    Response tmpRedirect(@PathParam("p") String p,
            @PathParam("testname") String testname);

    @Path("post-redirect")
    @POST
    Response postRedirect(String testname);

    @GET
    @Path("movedPermanently/{p}/{testname}")
    Response movedPermanently(@PathParam("p") String p,
            @PathParam("testname") String testname);

    @GET
    @Path("found/{p}/{testname}")
    Response found(@PathParam("p") String p,
            @PathParam("testname") String testname);

    @GET
    @Path("ping")
    String ping();

    @GET
    @Path("redirect/ping")
    Response redirectPing();
}

==> resteasy-microprofile-parent-2.0.0.Final-source-release.zip: resteasy-microprofile-parent-2.0.0.Final/testsuite/integration-tests/src/test/java/org/jboss/resteasy/microprofile/test/client/integration/resource/FollowRedirectsServiceIntf.java <==
/*
 * JBoss, Home of Professional Open Source.
 *
 * Copyright 2021 Red Hat, Inc., and individual contributors
 * as indicated by the @author tags.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jboss.resteasy.microprofile.test.client.integration.resource;

import java.util.List;

import jakarta.inject.Singleton;
import jakarta.ws.rs.GET;
import jakarta.ws.rs.POST;
import jakarta.ws.rs.Path;
import jakarta.ws.rs.PathParam;
import jakarta.ws.rs.core.Response;

import org.eclipse.microprofile.rest.client.inject.RegisterRestClient;

@RegisterRestClient(configKey = "ckName")
@Path("/theService")
@Singleton
public interface FollowRedirectsServiceIntf {
    @GET
    @Path("get")
    List<String> getList();

    @GET
    @Path("tmpRedirect/{p}/{testname}")
    Response tmpRedirect(@PathParam("p") String p,
            @PathParam("testname") String testname);

    @Path("post-redirect")
    @POST
    Response postRedirect(String testname);

    @GET
    @Path("movedPermanently/{p}/{testname}")
    Response movedPermanently(@PathParam("p") String p,
            @PathParam("testname") String testname);

    @GET
    @Path("found/{p}/{testname}")
    Response found(@PathParam("p") String p,
            @PathParam("testname") String testname);

    @GET
    @Path("ping")
    String ping();

    @GET
    @Path("redirect/ping")
    Response redirectPing();
}
